@@ -6,11 +6,12 @@ use base qw/Class::Accessor/;
 use Data::ICal::Property;
 use Carp;
 
+use constant CRLF => "\x0d\x0a";
+
 =head1 NAME
 
 Data::ICal::Entry - Represents an entry in an iCalendar file
 
-
 =head1 SYNOPSIS
 
     my $vtodo = Data::ICal::Entry::Todo->new();
@@ -21,22 +22,23 @@ Data::ICal::Entry - Represents an entry in an iCalendar file
     $calendar->add_entry($vtodo);
 
     $event->add_entry($alarm); 
-  
+
 =head1 DESCRIPTION
 
-A L<Data::ICal::Entry> object represents a single entry in an iCalendar file.
-(Note that the iCalendar RFC refers to entries as "components".)  iCalendar
-defines several types of entries, such as events and to-do lists; each of
-these corresponds to a subclass of L<Data::ICal::Entry> (though only to-do
-lists and events are currently implemented).  L<Data::ICal::Entry> should be treated
-as an abstract base class -- all objects created should be of its subclasses.
-The entire calendar itself (the L<Data::ICal> object) is also represented
+A L<Data::ICal::Entry> object represents a single entry in an
+iCalendar file.  (Note that the iCalendar RFC refers to entries as
+"components".)  iCalendar defines several types of entries, such as
+events and to-do lists; each of these corresponds to a subclass of
+L<Data::ICal::Entry> (though only to-do lists and events are currently
+implemented).  L<Data::ICal::Entry> should be treated as an abstract
+base class -- all objects created should be of its subclasses.  The
+entire calendar itself (the L<Data::ICal> object) is also represented
 as a L<Data::ICal::Entry> object.
 
-Each entry has an entry type (such as C<VCALENDAR> or C<VEVENT>), a series
-of "properties", and possibly some sub-entries.  (Only the root L<Data::ICal>
-object can have sub-entries, except for alarm entries contained in events and
-to-dos (not yet implemented).)
+Each entry has an entry type (such as C<VCALENDAR> or C<VEVENT>), a
+series of "properties", and possibly some sub-entries.  (Only the root
+L<Data::ICal> object can have sub-entries, except for alarm entries
+contained in events and to-dos (not yet implemented).)
 
 =head1 METHODS
 
@@ -50,28 +52,37 @@ Creates a new entry object with no properties or sub-entries.
 
 sub new {
     my $class = shift;
-    my $self = $class->SUPER::new;
-    $self->set(properties => {});
-    $self->set(entries => []);
+    my $self  = $class->SUPER::new;
+    $self->set( properties => {} );
+    $self->set( entries    => [] );
     return $self;
 }
 
-=head2 as_string
+=head2 as_string [ crlf => C<CRLF> ]
 
-Returns the entry as an appropriately formatted string (with trailing newline).
+Returns the entry as an appropriately formatted string (with trailing
+newline).
 
-Properties are returned in alphabetical order, with multiple properties of the same name
-returned in the order added.  (Property order is unimportant
-in iCalendar, and this makes testing easier.)
+Properties are returned in alphabetical order, with multiple
+properties of the same name returned in the order added.  (Property
+order is unimportant in iCalendar, and this makes testing easier.)
 
 If any mandatory property is missing, issues a warning.
 
+The string to use as a newline can optionally be specified by giving
+the a C<crlf> argument, which defaults to C<\x0d\x0a>, per RFC 2445
+spec; this option is primarily for backwards compatability with
+versions of this module before 0.16.
+
 =cut
 
 sub as_string {
     my $self = shift;
-    my %args = (@_);
-    my $output = $self->header;
+    my %args = (
+        crlf => CRLF,
+        @_
+    );
+    my $output = $self->header(%args);
 
     for my $name (
         $self->mandatory_unique_properties,
@@ -80,7 +91,7 @@ sub as_string {
     {
         carp "Mandatory property for " . ( ref $self ) . " missing: $name"
             unless $self->properties->{$name}
-            and @{ $self->properties->{$name} };
+                and @{ $self->properties->{$name} };
     }
 
     for my $name ( sort keys %{ $self->properties } ) {
@@ -91,19 +102,21 @@ sub as_string {
     for my $entry ( @{ $self->entries } ) {
         $output .= $entry->as_string(%args);
     }
-    $output .= $self->footer;
+    $output .= $self->footer(%args);
 
     return $output;
 }
 
 =head2 add_entry $entry
 
-Adds an entry to this entry.  (According to the standard, this should only be called
-on either a to-do or event entry with an alarm entry, or on a calendar entry (L<Data::ICal>)
-with a to-do, event, journal, timezone, or free/busy entry.)
+Adds an entry to this entry.  (According to the standard, this should
+only be called on either a to-do or event entry with an alarm entry,
+or on a calendar entry (L<Data::ICal>) with a to-do, event, journal,
+timezone, or free/busy entry.)
 
-Returns true if the entry was successfully added, and false otherwise (perhaps because you
-tried to add an entry of an invalid type, but this check hasn't been implemented yet). 
+Returns true if the entry was successfully added, and false otherwise
+(perhaps because you tried to add an entry of an invalid type, but
+this check hasn't been implemented yet).
 
 =cut
 
@@ -127,8 +140,9 @@ __PACKAGE__->mk_ro_accessors('entries');
 
 =head2 properties
 
-Returns a reference to the hash of properties of this entry.  The keys are property names and
-the values are array references containing L<Data::ICal::Property> objects.
+Returns a reference to the hash of properties of this entry.  The keys
+are property names and the values are array references containing
+L<Data::ICal::Property> objects.
 
 =cut
 
@@ -136,7 +150,8 @@ __PACKAGE__->mk_ro_accessors('properties');
 
 =head2 property
 
-Given a property name returns a reference to the array of L<Data::ICal::Property> objects.
+Given a property name returns a reference to the array of
+L<Data::ICal::Property> objects.
 
 =cut
 
@@ -148,19 +163,20 @@ sub property {
 
 =head2 add_property $propname => $propval
 
-Creates a new L<Data::ICal::Property> object with name C<$propname> and value
-C<$propval> and adds it to the event.
+Creates a new L<Data::ICal::Property> object with name C<$propname>
+and value C<$propval> and adds it to the event.
 
-If the property is not known to exist for that object type and does not begin
-with C<X->, issues a warning.
+If the property is not known to exist for that object type and does
+not begin with C<X->, issues a warning.
 
 If the property is known to be unique, replaces the original property.
 
-To specify parameters for the property, let C<$propval> be a two-element array reference
-where the first element is the property value and the second element is a hash reference.
-The keys of the hash are parameter names; the values should be either strings or array references
-of strings, depending on whether the parameter should have one or multiple (to be comma-separated)
-values.
+To specify parameters for the property, let C<$propval> be a
+two-element array reference where the first element is the property
+value and the second element is a hash reference.  The keys of the
+hash are parameter names; the values should be either strings or array
+references of strings, depending on whether the parameter should have
+one or multiple (to be comma-separated) values.
 
 Examples of setting parameters:
 
@@ -174,9 +190,8 @@ sub add_property {
     my $prop = lc shift;
     my $val  = shift;
 
-
     return unless defined $prop;
-    
+
     unless ( $self->is_property($prop) or $prop =~ /^x-/i ) {
         carp "Unknown property for " . ( ref $self ) . ": $prop";
     }
@@ -192,20 +207,23 @@ sub add_property {
     my ( $prop_value, $param_hash ) = @$val;
 
     my $p = Data::ICal::Property->new( $prop => $prop_value, $param_hash );
-    $p->vcal10( $self-> vcal10 );
-    
+    $p->vcal10( $self->vcal10 );
+
     push @{ $self->properties->{$prop} }, $p;
 }
 
 =head2 add_properties $propname1 => $propval1, [$propname2 => $propname2, ...]
 
-Convenience function to call C<add_property> several times with a list of properties.
+Convenience function to call C<add_property> several times with a list
+of properties.
 
-This method is guaranteed to call add C<add_property> on them in the order given, so that
-unique properties given later in the call will take precedence over those given earlier.
-(This is unrelated to the order of properties when the entry is rendered as a string, though.)
+This method is guaranteed to call add C<add_property> on them in the
+order given, so that unique properties given later in the call will
+take precedence over those given earlier.  (This is unrelated to the
+order of properties when the entry is rendered as a string, though.)
 
-Parameters for the properties are specified in the same way as in C<add_property>.
+Parameters for the properties are specified in the same way as in
+C<add_property>.
 
 =cut
 
@@ -226,9 +244,10 @@ sub add_properties {
 
 =head2 mandatory_unique_properties 
 
-Subclasses should override this method (which returns an empty list by default)
-to provide a list of lower case strings identifying the properties which must appear exactly
-once in the subclass's entry type.
+Subclasses should override this method (which returns an empty list by
+default) to provide a list of lower case strings identifying the
+properties which must appear exactly once in the subclass's entry
+type.
 
 =cut
 
@@ -236,9 +255,10 @@ sub mandatory_unique_properties { () }
 
 =head2 mandatory_repeatable_properties 
 
-Subclasses should override this method (which returns an empty list by default)
-to provide a list of lower case strings identifying the properties which must appear at least
-once in the subclass's entry type.
+Subclasses should override this method (which returns an empty list by
+default) to provide a list of lower case strings identifying the
+properties which must appear at least once in the subclass's entry
+type.
 
 =cut
 
@@ -246,9 +266,10 @@ sub mandatory_repeatable_properties { () }
 
 =head2 optional_unique_properties 
 
-Subclasses should override this method (which returns an empty list by default)
-to provide a list of lower case strings identifying the properties which must appear at most
-once in the subclass's entry type.
+Subclasses should override this method (which returns an empty list by
+default) to provide a list of lower case strings identifying the
+properties which must appear at most once in the subclass's entry
+type.
 
 =cut
 
@@ -256,9 +277,10 @@ sub optional_unique_properties { () }
 
 =head2 optional_repeatable_properties
 
-Subclasses should override this method (which returns an empty list by default)
-to provide a list of lower case strings identifying the properties which may appear zero,
-one, or more times in the subclass's entry type.
+Subclasses should override this method (which returns an empty list by
+default) to provide a list of lower case strings identifying the
+properties which may appear zero, one, or more times in the subclass's
+entry type.
 
 =cut
 
@@ -266,8 +288,9 @@ sub optional_repeatable_properties { () }
 
 =head2 is_property $name
 
-Returns a boolean value indicating whether or not the property C<$name> is known to the class
-(that is, if it's listed in C<(mandatory/optional)_(unique/repeatable)_properties>).
+Returns a boolean value indicating whether or not the property
+C<$name> is known to the class (that is, if it's listed in
+C<(mandatory/optional)_(unique/repeatable)_properties>).
 
 =cut
 
@@ -282,8 +305,9 @@ sub is_property {
 
 =head2 is_mandatory $name
 
-Returns a boolean value indicating whether or not the property C<$name> is known to the class as mandatory
-(that is, if it's listed in C<mandatory_(unique/repeatable)_properties>).
+Returns a boolean value indicating whether or not the property
+C<$name> is known to the class as mandatory (that is, if it's listed
+in C<mandatory_(unique/repeatable)_properties>).
 
 =cut
 
@@ -296,8 +320,9 @@ sub is_mandatory {
 
 =head2 is_optional $name
 
-Returns a boolean value indicating whether or not the property C<$name> is known to the class as optional
-(that is, if it's listed in C<optional_(unique/repeatable)_properties>).
+Returns a boolean value indicating whether or not the property
+C<$name> is known to the class as optional (that is, if it's listed in
+C<optional_(unique/repeatable)_properties>).
 
 =cut
 
@@ -310,8 +335,9 @@ sub is_optional {
 
 =head2 is_unique $name
 
-Returns a boolean value indicating whether or not the property C<$name> is known to the class as unique
-(that is, if it's listed in C<(mandatory/optional)_unique_properties>).
+Returns a boolean value indicating whether or not the property
+C<$name> is known to the class as unique (that is, if it's listed in
+C<(mandatory/optional)_unique_properties>).
 
 =cut
 
@@ -324,8 +350,9 @@ sub is_unique {
 
 =head2 is_repeatable $name
 
-Returns a boolean value indicating whether or not the property C<$name> is known to the class as repeatable
-(that is, if it's listed in C<(mandatory/optional)_repeatable_properties>).
+Returns a boolean value indicating whether or not the property
+C<$name> is known to the class as repeatable (that is, if it's listed
+in C<(mandatory/optional)_repeatable_properties>).
 
 =cut
 
@@ -338,8 +365,8 @@ sub is_repeatable {
 
 =head2 ical_entry_type
 
-Subclasses should override this method to provide the identifying type name of the entry
-(such as C<VCALENDAR> or C<VTODO>).
+Subclasses should override this method to provide the identifying type
+name of the entry (such as C<VCALENDAR> or C<VTODO>).
 
 =cut
 
@@ -347,10 +374,11 @@ sub ical_entry_type {'UNDEFINED'}
 
 =head2 vcal10 [$bool]
 
-Gets or sets a boolean saying whether this entry should be interpreted as vCalendar
-1.0 (as opposed to iCalendar 2.0).  Generally, you can just set this on your
-main L<Data::ICal> object when you construct it; C<add_entry> automatically makes
-sure that sub-entries end up with the same value as their parents.
+Gets or sets a boolean saying whether this entry should be interpreted
+as vCalendar 1.0 (as opposed to iCalendar 2.0).  Generally, you can
+just set this on your main L<Data::ICal> object when you construct it;
+C<add_entry> automatically makes sure that sub-entries end up with the
+same value as their parents.
 
 =cut
 
@@ -364,7 +392,11 @@ Returns the header line for the entry (including trailing newline).
 
 sub header {
     my $self = shift;
-    return 'BEGIN:' . $self->ical_entry_type . "\n";
+    my %args = (
+        crlf => CRLF,
+        @_
+    );
+    return 'BEGIN:' . $self->ical_entry_type . $args{crlf};
 }
 
 =head2 footer
@@ -375,7 +407,11 @@ Returns the footer line for the entry (including trailing newline).
 
 sub footer {
     my $self = shift;
-    return 'END:' . $self->ical_entry_type . "\n";
+    my %args = (
+        crlf => CRLF,
+        @_
+    );
+    return 'END:' . $self->ical_entry_type . $args{crlf};
 }
 
 # mapping of event types to class (under the Data::Ical::Event namespace)
@@ -391,7 +427,7 @@ my %_generic = (
 
 =head2 parse_object
 
-Translate a L<Text::vFile::asData> sub object into the appropriate 
+Translate a L<Text::vFile::asData> sub object into the appropriate
 L<Data::iCal::Event> subtype.
 
 =cut 
@@ -414,7 +450,7 @@ sub parse_object {
     } elsif ( my $sub = $self->can( '_parse_' . lc($type) ) ) {
         $new_self = $self->$sub($object);
 
-        # bitch
+        # complain
     } else {
         warn "Can't parse type $type yet";
         return;
@@ -497,7 +533,7 @@ sub _parse_generic_event {
                 $occurence->{value} =~ s/\\([;,\\])/$1/g;
                 $occurence->{value} =~ s/\\n/\n/ig;
             }
-            
+
             # handle optional params and 'normal' key/value pairs
             # TODO: line wrapping?
             if ( $occurence->{param} ) {
@@ -513,12 +549,12 @@ sub _parse_generic_event {
 
 =head1 AUTHOR
 
-Jesse Vincent  C<< <jesse@bestpractical.com> >> with David Glasser and Simon Wistow
-
+Jesse Vincent C<< <jesse@bestpractical.com> >> with David Glasser,
+Simon Wistow, and Alex Vandiver
 
 =head1 LICENCE AND COPYRIGHT
 
-Copyright (c) 2005, Best Practical Solutions, LLC.  All rights reserved.
+Copyright (c) 2005 - 2009, Best Practical Solutions, LLC.  All rights reserved.
 
 This module is free software; you can redistribute it and/or
 modify it under the same terms as Perl itself. See L<perlartistic>.
